@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 25 Mar 2012                                              }
+{ last modified: 31 Mar 2012                                              }
 {*************************************************************************/
 
 #include "qkineticwidget.h"
@@ -359,19 +359,7 @@ void QKineticWidget::repositionChildrenV(int itemsHeight, int rows)
 
 void QKineticWidget::centerWidgetV(const QWidget *widget)
 {
-    /*
-    QWidget* target = NULL;
-    foreach(QObject* child, children())
-        if(widget == child)
-        {
-            target = child;
-            break;
-        }
-    if(!target)
-        return;
-    */
-
-    int y = -widget->y()+(height()-widget->height())/2;
+    int y = getY()-widget->y()+(height()-widget->height())/2;
     if(y > 0)
     {
         y = 0;
@@ -381,7 +369,7 @@ void QKineticWidget::centerWidgetV(const QWidget *widget)
         if(y < minY)
             y = minY;
     }
-    scrollY(y);
+    setY(y);
 }
 
 void QKineticWidget::setCssNormal(const QString &css)
